@@ -1,7 +1,7 @@
 from datetime import datetime
-from typing import Dict, List
+from typing import Dict, List, Union
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictFloat
 
 from learninghouse import versions
 from learninghouse.models import LearningHouseVersions
@@ -22,6 +22,7 @@ class BrainInfo(BaseModel):
     trained_at: datetime = Field(
         None, example=datetime.now().strftime('%Y-%m-%dT%H:%M:%S.%f'))
     versions: LearningHouseVersions = Field(None, example=versions)
+    actual_versions: bool = Field(True)
 
 
 class BrainTrainingRequest(DictModel):
@@ -42,7 +43,7 @@ class BrainTrainingRequest(DictModel):
     for this `feature` will be assumed.
     """
 
-    __root__: Dict[str, bool | int | float | str | None] = Field(None, example={
+    __root__: Dict[str, Union[StrictBool, StrictInt, StrictFloat, str, None]] = Field(None, example={
         'azimuth': 321.4441223144531,
         'elevation': -19.691608428955078,
         'rain_gauge': 0.0,
@@ -56,7 +57,7 @@ class BrainTrainingRequest(DictModel):
 
 
 class BrainPredictionRequest(DictModel):
-    __root__: Dict[str,  bool | int | float | str | None] = Field(None, example={
+    __root__: Dict[str,  Union[StrictBool, StrictInt, StrictFloat, str, None]] = Field(None, example={
         'azimuth': 321.4441223144531,
         'elevation': -19.691608428955078,
         'rain_gauge': 0.0,
@@ -70,10 +71,11 @@ class BrainPredictionRequest(DictModel):
 
 class BrainPredictionResult(BaseModel):
     brain: BrainInfo
-    preprocessed: Dict[str, int | float | str | bool] = Field(None, example={
+    preprocessed: Dict[str, Union[StrictBool, StrictInt, StrictFloat, str]] = Field(None, example={
         'azimuth': 321.4441223144531,
         'elevation': -19.691608428955078,
         'rain_gauge': 0.0,
         'pressure_trend_1h_falling': 1
     })
-    prediction: bool | float = Field(None, example=False)
+    prediction: Union[StrictBool, StrictInt, StrictFloat] = Field(
+        None, example=False)
